Leave-one-out pseudo-crossvalidation for graph_lme models assuming observations at the vertices of metric graphs
Source: R/graph_inference.R
posterior_crossvalidation_loo.RdThis function performs pseudo-crossvalidation by computing leave-one-out predictions using the posterior distribution from a fitted model. In pseudo-crossvalidation, the model parameters are kept fixed at the values estimated from the full dataset (those provided in the object), rather than re-estimating them for each fold.
Arguments
- object
A fitted model using the
graph_lme()function or a named list of fitted objects using thegraph_lme()function.- factor
Which factor to multiply the scores. The default is 1.
- tibble
Return the scores as a
tidyr::tibble()- which_repl
Which replicates to consider?