graph_lme models assuming observations at
the vertices of metric graphsThis function performs pseudo-crossvalidation by computing leave-one-out predictions using the posterior distribution from a fitted model. In pseudo-crossvalidation, the model parameters are kept fixed at the values estimated from the full dataset (those provided in the object), rather than re-estimating them for each fold.
posterior_crossvalidation_loo(
object,
factor = 1,
tibble = TRUE,
which_repl = NULL
)Vector with the posterior expectations and variances as well as mean absolute error (MAE), root mean squared errors (RMSE), and three negatively oriented proper scoring rules: log-score, CRPS, and scaled CRPS.
A fitted model using the graph_lme() function or a named list of fitted objects using the graph_lme() function.
Which factor to multiply the scores. The default is 1.
Return the scores as a tidyr::tibble()
Which replicates to consider?